( cd usr/X11R6/lib/X11/xfm ; rm -rf bitmaps )
( cd usr/X11R6/lib/X11/xfm ; ln -sf /usr/X11R6/include/X11/bitmaps bitmaps )
( cd usr/X11R6/lib/X11/xfm ; rm -rf icons )
( cd usr/X11R6/lib/X11/xfm ; ln -sf /usr/X11R6/include/X11/pixmaps icons )
( cd usr/X11R6/lib/X11/xfm ; rm -rf pixmaps )
( cd usr/X11R6/lib/X11/xfm ; ln -sf /usr/X11R6/include/X11/pixmaps pixmaps )
